summaryrefslogtreecommitdiffstats
path: root/src/3rdparty/sqlite/parse.c
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2013-05-07 21:58:34 -0500
committerTimothy Pearson <[email protected]>2013-05-07 21:58:34 -0500
commitc740211ffba3330d951f4c3ddefea8edf23a01cd (patch)
tree0a8b7641d3c5b576d18a2f7912c75fc600f494e2 /src/3rdparty/sqlite/parse.c
parent8a4eacb6185de3653f6ae401c352aef833a9e72a (diff)
downloadtqt3-c740211ffba3330d951f4c3ddefea8edf23a01cd.tar.gz
tqt3-c740211ffba3330d951f4c3ddefea8edf23a01cd.zip
Automated update from Qt3
Diffstat (limited to 'src/3rdparty/sqlite/parse.c')
-rw-r--r--src/3rdparty/sqlite/parse.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/3rdparty/sqlite/parse.c b/src/3rdparty/sqlite/parse.c
index 2fd6ae395..463536915 100644
--- a/src/3rdparty/sqlite/parse.c
+++ b/src/3rdparty/sqlite/parse.c
@@ -711,7 +711,7 @@ static const YYCODETYPE yyFallback[] = {
0, /* FLOAT => nothing */
0, /* NULL => nothing */
0, /* PRIMARY => nothing */
- 0, /* UNITQUE => nothing */
+ 0, /* UNIQUE => nothing */
0, /* CHECK => nothing */
0, /* REFERENCES => nothing */
0, /* COLLATE => nothing */
@@ -840,7 +840,7 @@ static const char *yyTokenName[] = {
"STAR", "SLASH", "REM", "CONCAT",
"UMINUS", "UPLUS", "BITNOT", "STRING",
"JOIN_KW", "INTEGER", "CONSTRAINT", "DEFAULT",
- "FLOAT", "NULL", "PRIMARY", "UNITQUE",
+ "FLOAT", "NULL", "PRIMARY", "UNIQUE",
"CHECK", "REFERENCES", "COLLATE", "ON",
"DELETE", "UPDATE", "INSERT", "SET",
"DEFERRABLE", "FOREIGN", "DROP", "UNION",
@@ -935,7 +935,7 @@ static const char *yyRuleName[] = {
/* 53 */ "ccons ::= NULL onconf",
/* 54 */ "ccons ::= NOT NULL onconf",
/* 55 */ "ccons ::= PRIMARY KEY sortorder onconf",
- /* 56 */ "ccons ::= UNITQUE onconf",
+ /* 56 */ "ccons ::= UNIQUE onconf",
/* 57 */ "ccons ::= CHECK LP expr RP onconf",
/* 58 */ "ccons ::= REFERENCES nm idxlist_opt refargs",
/* 59 */ "ccons ::= defer_subclause",
@@ -962,7 +962,7 @@ static const char *yyRuleName[] = {
/* 80 */ "conslist ::= tcons",
/* 81 */ "tcons ::= CONSTRAINT nm",
/* 82 */ "tcons ::= PRIMARY KEY LP idxlist RP onconf",
/* 83 */ "tcons ::= UNITQUE LP idxlist RP onconf",
/* 84 */ "tcons ::= CHECK expr onconf",
/* 85 */ "tcons ::= FOREIGN KEY LP idxlist RP REFERENCES nm idxlist_opt refargs defer_subclause_opt",
/* 86 */ "defer_subclause_opt ::=",
@@ -1115,7 +1115,7 @@ static const char *yyRuleName[] = {
/* 233 */ "expritem ::= expr",
/* 234 */ "expritem ::=",
/* 235 */ "cmd ::= CREATE uniqueflag INDEX nm ON nm dbnm LP idxlist RP onconf",
- /* 236 */ "uniqueflag ::= UNITQUE",
+ /* 236 */ "uniqueflag ::= UNIQUE",
/* 237 */ "uniqueflag ::=",
/* 238 */ "idxlist_opt ::=",
/* 239 */ "idxlist_opt ::= LP idxlist RP",
@@ -2183,7 +2183,7 @@ static void yy_reduce(
#line 191 "parse.y"
{sqliteCreateIndex(pParse,0,0,0,yymsp[0].minor.yy372,0,0);}
#line 2185 "parse.c"
/* No destructor defined for UNITQUE */
break;
case 57:
/* No destructor defined for CHECK */
@@ -2342,7 +2342,7 @@ static void yy_reduce(
#line 238 "parse.y"
{sqliteCreateIndex(pParse,0,0,yymsp[-2].minor.yy320,yymsp[0].minor.yy372,0,0);}
#line 2344 "parse.c"
/* No destructor defined for UNITQUE */
/* No destructor defined for LP */
/* No destructor defined for RP */
break;
@@ -3428,7 +3428,7 @@ static void yy_reduce(
#line 740 "parse.y"
{ yygotominor.yy372 = OE_Abort; }
#line 3430 "parse.c"
/* No destructor defined for UNITQUE */
break;
case 237:
#line 741 "parse.y"
@@ -962,7 +962,7 @@ static const char *yyRuleName[] = {
/* 81 */ "tcons ::= CONSTRAINT nm",
/* 82 */ "tcons ::= PRIMARY KEY LP idxlist RP onconf",
- /* 83 */ "tcons ::= UNITQUE LP idxlist RP onconf",
+ /* 83 */ "tcons ::= UNIQUE LP idxlist RP onconf",
/* 84 */ "tcons ::= CHECK expr onconf",
/* 85 */ "tcons ::= FOREIGN KEY LP idxlist RP REFERENCES nm idxlist_opt refargs defer_subclause_opt",
@@ -2183,7 +2183,7 @@ static void yy_reduce(
{sqliteCreateIndex(pParse,0,0,0,yymsp[0].minor.yy372,0,0);}
#line 2185 "parse.c"
- /* No destructor defined for UNITQUE */
+ /* No destructor defined for UNIQUE */
break;
case 57:
@@ -2342,7 +2342,7 @@ static void yy_reduce(
{sqliteCreateIndex(pParse,0,0,yymsp[-2].minor.yy320,yymsp[0].minor.yy372,0,0);}
#line 2344 "parse.c"
- /* No destructor defined for UNITQUE */
+ /* No destructor defined for UNIQUE */
/* No destructor defined for LP */
/* No destructor defined for RP */
@@ -3428,7 +3428,7 @@ static void yy_reduce(
{ yygotominor.yy372 = OE_Abort; }
#line 3430 "parse.c"
- /* No destructor defined for UNITQUE */
+ /* No destructor defined for UNIQUE */
break;
case 237: